<?php

namespace Drupal\react_comments;

use Drupal\node\Entity\Node;

/**
 * Provides a method to check drupal comment settings (open/closed/hidden)
 */
trait CommentSettingsTrait {

  function getCommentSettings($nid) {
    $node = Node::load($nid);

    $status = null;

    // Check to see if the node has any comment fields.
    foreach ($node->getFieldDefinitions() as $field_name => $definition) {
      $field = $node->get($field_name);
      if (is_a($field, 'Drupal\comment\CommentFieldItemList')) {
        $status = $field->status;
        // We're assuming there's only one comment field per node. Seems sensible...
        break;
      }
    }
    if (is_null($status)) {
      // No comment field found.
      return false;
    }
    else if (($status === '1') || ($status === 1)) {
      return 'closed';
    }
    else if (($status === '2') || ($status === 2)) {
      return 'open';
    }
    else {
      // shouldn't need this as comment module handles hidden comments already
      return 'hidden';
    }
  }
}
